<?php

namespace EventPortal\Tests\Feature\Admin\Delegate;

use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Spatie\Snapshots\MatchesSnapshots;

class DelegateUpdateTest extends TestCase
{
    use RefreshDatabase, MatchesSnapshots, SeedRolesAndPermissions;

    /** @test **/
    public function can_update_a_delegate(): void
    {
        $user = factory(User::class)->create([
            'first_name' => 'originalFirstName',
            'last_name' => 'originalLastName',
            'email' => 'original@example.com',
        ]);
        $delegate = factory(Delegate::class)->create([
            'user_id' => $user->id,
        ]);

        $this
            ->actingAsSuperAdmin()
            ->followingRedirects()
            ->post(route('admin.delegate.update', $delegate), [
                'first_name' => 'updatedFirstName',
                'last_name' => 'updatedLastName',
                'email' => 'updated@example.com',
            ])
            ->assertOk();
        $this->assertEquals(route('admin.delegate.show', $delegate), url()->current());

        $updatedDelegate = Delegate::first();
        $this->assertEquals('updatedFirstName', $updatedDelegate->user->first_name);
        $this->assertEquals('updatedLastName', $updatedDelegate->user->last_name);
        $this->assertEquals('updated@example.com', $updatedDelegate->user->email);
    }
}
